@@ -72,7 +72,10 @@ def preprocess_source(source, options, nvcc):
 
     unlink(source_path)
 
-    return stdout.decode("utf-8", "replace")
+    preprocessed_str = stdout.decode("utf-8", "replace")
+
+    # remove the temporary filename from the preprocessed source code to get reproducible hashes
+    return preprocessed_str.replace(os.path.basename(source_path), "")
 
 
 def compile_plain(source, options, keep, nvcc, cache_dir, target="cubin"):
@@ -203,9 +206,12 @@ def _get_per_user_string():
 
 
 def _find_pycuda_include_path():
-    from pkg_resources import Requirement, resource_filename
+    import importlib.util
+    import os
 
-    return resource_filename(Requirement.parse("pycuda"), "pycuda/cuda")
+    return os.path.abspath(
+        os.path.join(importlib.util.find_spec("pycuda").origin,
+                     os.path.pardir, "cuda"))
 
 
 DEFAULT_NVCC_FLAGS = [
