@@ -88,7 +88,7 @@ def _create_vector_types():
                     eval(
                         "lambda %s: array((%s), dtype=my_dtype)"
                         % (my_field_names, my_field_names),
-                        dict(array=np.array, my_dtype=dtype),
+                        {"array": np.array, "my_dtype": dtype},
                     )
                 ),
             )
@@ -389,7 +389,7 @@ class GPUArray:
         return self.get(ary=ary, async_=True, stream=stream)
 
     def copy(self):
-        new = GPUArray(self.shape, self.dtype, self.allocator)
+        new = GPUArray(self.shape, self.dtype, self.allocator, strides=self.strides)
         _memcpy_discontig(new, self)
         return new
 
